@@ -33,7 +33,7 @@ def parse_value_by_type(s: str, t: int) -> typing.Any:
         return None
 
     if t == 0:
-        return t
+        return str(s)
     elif t == 1:
         return int(s)
     elif t == 2:
